@@ -20,7 +20,7 @@ from ._core import (
 )
 from ._version import server_version, version
 from .requests import Request
-from .responses import RelayResponse, Response, StaticResponse, StreamResponse
+from .responses import DelayedResponse, RelayResponse, Response, StaticResponse, StreamResponse
 
 __all__ = (
     "App",
@@ -35,7 +35,7 @@ __all__ = (
     "default_app", "default_handler", "default_logger",
     "version", "server_version",
     "Request",
-    "Response", "StaticResponse", "StreamResponse", "RelayResponse",
+    "Response", "StaticResponse", "StreamResponse", "RelayResponse", "DelayedResponse",
 )
 
 __version__ = version
