@@ -17,7 +17,7 @@ class Formatter(logging.Formatter):
     def format(self, record: LogRecord) -> str:
         request = getattr(record, "jj_request", None)
         response = getattr(record, "jj_response", None)
-        if response is not None:
+        if (response is not None) and (request is not None):
             return self.format_response(response, request, record)
         elif request is not None:
             return self.format_request(request, record)
