@@ -1,9 +1,11 @@
 from ._body_parser import BodyParser
 from ._history_adapter import HistoryAdapterType, default_history_adapter
+from ._history_formatter import HistoryFormatter, PrettyHistoryFormatter
 from ._history_item import HistoryItem
 from ._history_repository import HistoryRepository
 from ._history_request import HistoryRequest
 from ._history_response import HistoryResponse
 
 __all__ = ("HistoryRepository", "HistoryRequest", "HistoryResponse", "HistoryItem",
-           "HistoryAdapterType", "default_history_adapter", "BodyParser",)
+           "HistoryAdapterType", "default_history_adapter", "BodyParser",
+           "HistoryFormatter", "PrettyHistoryFormatter",)
